@@ -99,30 +99,16 @@ public:
 
     /**
      * Create a client that can be used to communicate with an MQTT server.
-     * This allows the caller to specify a user-defined persistence object,
-     * or use no persistence.
      * @param serverURI the address of the server to connect to, specified
      *  				as a URI.
      * @param clientId a client identifier that is unique on the server
-     *  			   being connected to
-     * @param persistence The user persistence structure. If this is null,
-     *  				  then no persistence is used.
+     *                 being connected to.
+     * @param persistence The desired persistence type.
      */
     client(
-        const string& serverURI, const string& clientId,
-        iclient_persistence* persistence = nullptr
+        const string& serverURI, const string& clientId = string{},
+        const persistence_type& persistence = NO_PERSISTENCE
     );
-    /**
-     * Create an async_client that can be used to communicate with an MQTT
-     * server.
-     * This uses file-based persistence in the specified directory.
-     * @param serverURI the address of the server to connect to, specified
-     *  				as a URI.
-     * @param clientId a client identifier that is unique on the server
-     *  			   being connected to
-     * @param persistDir The directory to use for persistence data
-     */
-    client(const string& serverURI, const string& clientId, const string& persistDir);
     /**
      * Create a client that can be used to communicate with an MQTT server,
      * which allows for off-line message buffering.
@@ -134,46 +120,32 @@ public:
      *  			   being connected to
      * @param maxBufferedMessages the maximum number of messages allowed to
      *  						  be buffered while not connected
-     * @param persistence The user persistence structure. If this is null,
-     *  				  then no persistence is used.
+     * @param persistence The desired persistence type.
      */
     client(
         const string& serverURI, const string& clientId, int maxBufferedMessages,
-        iclient_persistence* persistence = nullptr
+        const persistence_type& persistence = NO_PERSISTENCE
     );
     /**
      * Create a client that can be used to communicate with an MQTT server,
-     * which allows for off-line message buffering.
-     * This uses file-based persistence in the specified directory.
-     * @param serverURI the address of the server to connect to, specified
-     *  				as a URI.
-     * @param clientId a client identifier that is unique on the server
-     *  			   being connected to
-     * @param maxBufferedMessages the maximum number of messages allowed to
-     *  						  be buffered while not connected
-     * @param persistDir The directory to use for persistence data
-     */
-    client(
-        const string& serverURI, const string& clientId, int maxBufferedMessages,
-        const string& persistDir
-    );
-    /**
-     * Create an async_client that can be used to communicate with an MQTT
-     * server, which allows for off-line message buffering.
-     * This allows the caller to specify a user-defined persistence object,
-     * or use no persistence.
+     * which allows for off-line message buffering. This allows the caller
+     * to specify a user-defined persistence object, or use no persistence.
      * @param serverURI the address of the server to connect to, specified
      *  				as a URI.
      * @param clientId a client identifier that is unique on the server
      *  			   being connected to
      * @param opts The create options
-     * @param persistence The user persistence structure. If this is null,
-     *  				  then no persistence is used.
+     * @param persistence The desired persistence type.
      */
     client(
         const string& serverURI, const string& clientId, const create_options& opts,
-        iclient_persistence* persistence = nullptr
+        const persistence_type& persistence = NO_PERSISTENCE
     );
+    /**
+     * Create a client that can be used to communicate with an MQTT server.
+     * @param opts The create options
+     */
+    client(const create_options& opts);
     /**
      * Virtual destructor
      */
