@@ -40,7 +40,7 @@ using namespace mqtt;
 // NOTE: This test case requires network access. It uses one of
 //  	 the public available MQTT brokers
 #if defined(TEST_EXTERNAL_SERVER)
-static const std::string GOOD_SERVER_URI{"tcp://mqtt.eclipse.org:1883"};
+static const std::string GOOD_SERVER_URI{"tcp://mqtt.eclipseprojects.io:1883"};
 #else
 static const std::string GOOD_SERVER_URI{"tcp://localhost:1883"};
 #endif
